[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](LICENSE)

 # torchrecipes

**This library is currently under heavy development - if you have suggestions on the API or use-cases you'd like to be covered, please open an github issue or reach out. We'd love to hear about how you're using `torchrecipes`.**

`torchrecipes` is a prototype is built on top of PyTORCH and provides a set of reproduci-able, re-usable, ready-to-run RECIPES for training different types of models, across multiple domains, on PyTorch Lgihtning.

It aims ro provide reproduci-able "applications" built on top of PyTorch with good performance and easy reproduciability. Because this project builds on the pytorch ecosystem and requires significant investment, we'd love to hear from and work with
early adopters to shape the design. Please reach out on the issue tracker
if you're interested in using this for your project.


## Why `torchrecipes`?

The primary goal of the `torchrecipes` is to 10x ML development by providing standard blueprints to easily train production-ready ML models across environemnts (from local development to cluster deployment).

## Requirements
PyTorch Recipes (torchrecipes):
* python3 (3.8+)
* torch

## Installation
TODO

### Release

```bash
# install torchrecipes
pip install torchrecipes
```

## Contributing

We welcome PRs! See the [CONTRIBUTING](CONTRIBUTING.md) file.

## License

torchrecipes is BSD licensed, as found in the [LICENSE](LICENSE) file.
